@@ -9,14 +9,14 @@ Events is supposed to be an event module which sends webhooks to:
 """
 
 import logging
-from typing import Tuple
-from smtplib import SMTPException
+from typing import Tuple, List
 import json
 
 import requests
 
 import mail.aws_ses
 import mail.message
+from mail.exceptions import EmailException
 
 
 logging.basicConfig()
@@ -77,7 +77,7 @@ class EmailHook(WatchEvent):
                 data_ = str(data)
             self.email.body_text = data_
             self.email.send_mail()
-        except SMTPException as e:
+        except EmailException as e:
             logger.error(f"Error: '{str(e)}'.")
             return
 
@@ -105,9 +105,9 @@ class WebHook(WatchEvent):
     def __init__(self, name="", url="", url_safe="", realms: Tuple[str] = None):
         self.url = url
         self.url_safe = url_safe
+        super().__init__(name=name, description=f"To '{self.url_safe}'.", realms=realms)
         logger.debug(f"Webhook event URL '{self.url_safe}'.")
         logger.debug(f"Webhook event REALMS '{self.realms}'.")
-        super().__init__(name=name, description=f"To '{self.url_safe}'.", realms=realms)
 
     def _trigger(self, data=None, debug=False):
         if debug:
@@ -115,7 +115,10 @@ class WebHook(WatchEvent):
         response = None
         try:
             response = requests.post(self.url, json=data, headers=self.HEADERS)
-        except (requests.exceptions.MissingSchema) as e:
+        except (
+            requests.exceptions.MissingSchema,
+            requests.exceptions.RequestException,
+        ) as e:
             logger.error(f"Error: '{str(e)}'.")
         if not response:
             logger.error("No response.")
@@ -206,10 +209,12 @@ class AwsSesEmailHook(EmailHook):
     def __init__(
         self,
         name="",
-        # recipients:List[str]=None,
+        host: str = "",
+        port: int = 0,
+        recipients: List[str] = None,
         realms: Tuple[str] = None,
     ):
-        email = mail.aws_ses.AwsSesEmail()
+        email = mail.aws_ses.AwsSesEmail(host=host, port=port, recipients=recipients)
         if not email.subject:
             email.subject = name
 
